[Solar-svn] Revision 2874

pmjones at solarphp.com pmjones at solarphp.com
Sat Oct 13 08:53:06 CDT 2007


Solar_App_Bookmarks: [FIX] actionUser() and actionTag() no longer flash a backlink under RSS formats; this fixes errors when the user has live bookmarks in Firefox and the "back" link points to RSS feed pulled by the live bookmark.




Modified: trunk/Solar/App/Bookmarks.php
===================================================================
--- trunk/Solar/App/Bookmarks.php	2007-10-13 13:51:50 UTC (rev 2873)
+++ trunk/Solar/App/Bookmarks.php	2007-10-13 13:53:06 UTC (rev 2874)
@@ -585,8 +585,11 @@
         // get the total pages and row-count
         $total = $this->_bookmarks->countPagesByTags($tag_list, $params);
         
-        // flash forward the backlink in case we go to edit
-        $this->_session->setFlash('backlink', $this->_request->server('REQUEST_URI'));
+        // flash forward the backlink in case we go to edit, but only if this
+        // is a regular-format request
+        if (! $this->_format) {
+            $this->_session->setFlash('backlink', $this->_request->server('REQUEST_URI'));
+        }
         
         // assign the list of tags in use
         $this->tags_in_use   = $this->_tags->fetchAllWithCount(array(
@@ -651,14 +654,17 @@
             $total = $this->_bookmarks->countPages($params);
         }
         
-        // flash forward the backlink in case we go to edit
-        $this->_session->setFlash('backlink', $this->_request->server('REQUEST_URI'));
+        // flash forward the backlink in case we go to edit, but only if this
+        // is a regular-format request
+        if (! $this->_format) {
+            $this->_session->setFlash('backlink', $this->_request->server('REQUEST_URI'));
+        }
         
         // assign the list of tags in use
         $this->tags_in_use = $this->_tags->fetchAllByOwnerHandle(
             $owner_handle,
             array(
-            'order' => 'tags.name'
+                'order' => 'tags.name'
             )
         );
         




More information about the Solar-svn mailing list